@@ -4,7 +4,7 @@
     begin                : Sun Nov 5 2000
     copyright            : (C) 2000 by Sergio Moretti
     email                : sermore@libero.it
-    revision             : $Revision: 1.2 $
+    revision             : $Revision: 1.4 $
  ***************************************************************************/
 
 /***************************************************************************
@@ -24,11 +24,25 @@
 #include "ktransferkioimpl.h"
 #include "ktransferkio.h"
 
-KTransferKio::KTransferKio(KTransferKioImpl *impl) : KTransfer(impl) {
+KTransferKio::KTransferKio(KTransferKioImpl *impl) : KTransfer(impl) 
+{
 }
 
-KTransferKioImpl * KTransferKio::impl() const {
-  return dynamic_cast<KTransferKioImpl*>(KTransfer::impl());
+KTransferKioImpl * KTransferKio::impl() const 
+{
+   return dynamic_cast<KTransferKioImpl*>(KTransfer::impl());
+}
+ 
+// config
+
+bool KTransferKio::getDisableCookie() const
+{
+   return impl()->getDisableCookie();
+}
+
+void KTransferKio::setDisableCookie(bool v) const
+{
+   impl()->setDisableCookie(v);
 }
 
 #endif
