@@ -4,10 +4,8 @@
     begin                : Sun Nov 5 2000
     copyright            : (C) 2000 by Sergio Moretti
     email                : sermore@libero.it
-    revision             : $Revision: 1.1 $
- ***************************************************************************/
-
-/***************************************************************************
+    revision             : $Revision: 1.3 $
+ ***************************************************************************
  *                                                                         *
  *   This program is free software; you can redistribute it and/or modify  *
  *   it under the terms of the GNU General Public License as published by  *
@@ -25,20 +23,29 @@ class KTManager;
 class KTransferKioImpl;
 
 /**
-  *@author Sergio Moretti
-  */
+ * short Bridge class for @ref KTransferKioImpl objects.
+ * 
+ * @author Sergio Moretti
+ *
+ * @version $Id: ktransferkio.h,v 1.3 2001/03/05 20:59:23 sergio Exp $
+ */
 
-class KTransferKio : public KTransfer  {
-
-  friend class KObject;
-  friend class KTManager;
+class KTransferKio : public KTransfer 
+{
+   friend class KObject;
+   friend class KTManager;
 
 public: 
-  KTransferKio() {}
+   KTransferKio() {}
+
+   // config
+
+   bool getDisableCookie() const;
+   void setDisableCookie(bool v) const;
 
 protected:
-  KTransferKio(KTransferKioImpl *impl);
-  KTransferKioImpl * impl() const;
+   KTransferKio(KTransferKioImpl *impl);
+   KTransferKioImpl * impl() const;
 };
 
 #endif
